
from setuptools import setup

setup(name='burst_detection',
      version='0.1',
      description='Detect bursts in batched data using Kleinberg''s (2002) algorithm.',
      url='http://github.com/nmarinsek/burst_detection',
      author='Nikki Marinsek',
      author_email='nikki.marinsek@gmail.com',
      license='',
      packages=['burst_detection'],
      zip_safe=False)
